@@ -1,7 +1,7 @@
 # Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: CNic.pm,v 1.45 2007/04/26 16:16:07 gavin Exp $
+# $Id: CNic.pm,v 1.47 2007/07/24 11:35:59 gavin Exp $
 package WWW::CNic;
 use LWP;
 use LWP::ConnCache;
@@ -11,7 +11,7 @@ use Digest::MD5 qw(md5_hex);
 use vars qw($VERSION $CONNECTION_CACHE);
 use strict;
 
-our $VERSION = '0.22';
+our $VERSION = '0.24';
 
 =pod
 
@@ -64,7 +64,8 @@ Installing C<WWW::CNic> is as simple as:
 	make
 	make install
 
-=head1 PREREQUISITES
+=head1 PREREQUISITES		$self->{_command} eq 'list_outstanding_domains'	&& return $self->_list_outstanding_domains();
+
 
 =over
 
@@ -201,32 +202,34 @@ sub set {
 sub execute {
 	my $self = shift;
 	SWITCH: {
-		$self->{_command} eq 'whois'		&& return $self->_whois();
-		$self->{_command} eq 'search'		&& return $self->_search();
-		$self->{_command} eq 'suffixes'		&& return $self->_suffixes();
-		$self->{_command} eq 'create_handle'	&& return $self->_create_handle();
-		$self->{_command} eq 'handle_info'	&& return $self->_handle_info();
-		$self->{_command} eq 'register'		&& return $self->_register();
-		$self->{_command} eq 'register_idn'	&& return $self->_register(idn => 1);
-		$self->{_command} eq 'register_atgb'	&& return $self->_register_atgb();
-		$self->{_command} eq 'modify'		&& return $self->_modify();
-		$self->{_command} eq 'modify_handle'	&& return $self->_modify_handle();
-		$self->{_command} eq 'renewals'		&& return $self->_upcoming_renewals();
-		$self->{_command} eq 'list_domains'	&& return $self->_list_domains();
-		$self->{_command} eq 'issue_renewals'	&& return $self->_issue_renewals();
-		$self->{_command} eq 'get_pricing'	&& return $self->_get_pricing();
-		$self->{_command} eq 'delete'		&& return $self->_delete_domain();
-		$self->{_command} eq 'decline'		&& return $self->_decline_domain();
-		$self->{_command} eq 'undecline'	&& return $self->_undecline_domain();
-		$self->{_command} eq 'start_transfer'	&& return $self->_start_transfer();
-		$self->{_command} eq 'check_transfer'	&& return $self->_check_transfer();
-		$self->{_command} eq 'cancel_transfer'	&& return $self->_cancel_transfer();
-		$self->{_command} eq 'reactivate'	&& return $self->_reactivate_domain();
-		$self->{_command} eq 'push_domain'	&& return $self->_push_domain();
-		$self->{_command} eq 'auth_info'	&& return $self->_auth_info();
-		$self->{_command} eq 'poll_transfers'	&& return $self->_poll_transfers();
-		$self->{_command} eq 'approve_transfer'	&& return $self->_approve_transfer();
-		$self->{_command} eq 'reject_transfer'	&& return $self->_reject_transfer();
+		$self->{_command} eq 'whois'			&& return $self->_whois();
+		$self->{_command} eq 'search'			&& return $self->_search();
+		$self->{_command} eq 'suffixes'			&& return $self->_suffixes();
+		$self->{_command} eq 'create_handle'		&& return $self->_create_handle();
+		$self->{_command} eq 'handle_info'		&& return $self->_handle_info();
+		$self->{_command} eq 'register'			&& return $self->_register();
+		$self->{_command} eq 'register_idn'		&& return $self->_register(idn => 1);
+		$self->{_command} eq 'register_atgb'		&& return $self->_register_atgb();
+		$self->{_command} eq 'modify'			&& return $self->_modify();
+		$self->{_command} eq 'modify_handle'		&& return $self->_modify_handle();
+		$self->{_command} eq 'renewals'			&& return $self->_upcoming_renewals();
+		$self->{_command} eq 'list_domains'		&& return $self->_list_domains();
+		$self->{_command} eq 'issue_renewals'		&& return $self->_issue_renewals();
+		$self->{_command} eq 'get_pricing'		&& return $self->_get_pricing();
+		$self->{_command} eq 'delete'			&& return $self->_delete_domain();
+		$self->{_command} eq 'decline'			&& return $self->_decline_domain();
+		$self->{_command} eq 'undecline'		&& return $self->_undecline_domain();
+		$self->{_command} eq 'start_transfer'		&& return $self->_start_transfer();
+		$self->{_command} eq 'check_transfer'		&& return $self->_check_transfer();
+		$self->{_command} eq 'cancel_transfer'		&& return $self->_cancel_transfer();
+		$self->{_command} eq 'reactivate'		&& return $self->_reactivate_domain();
+		$self->{_command} eq 'push_domain'		&& return $self->_push_domain();
+		$self->{_command} eq 'auth_info'		&& return $self->_auth_info();
+		$self->{_command} eq 'poll_transfers'		&& return $self->_poll_transfers();
+		$self->{_command} eq 'approve_transfer'		&& return $self->_approve_transfer();
+		$self->{_command} eq 'reject_transfer'		&& return $self->_reject_transfer();
+		$self->{_command} eq 'list_outstanding_domains'	&& return $self->_list_outstanding_domains();
+		$self->{_command} eq 'submit_payment_batch'	&& return $self->_submit_payment_batch();
 		die("Invalid command '$self->{_command}'");
 	}
 }
@@ -524,7 +527,7 @@ sub _issue_renewals {
 				user		=> $self->{_username},
 				password	=> $self->_crypt_md5($self->{_password}),
 				test		=> $self->{_test},
-				period		=> $self->{_period},
+				period		=> $self->{_params}->{period},
 				immediate	=> $self->{_params}->{immediate},
 			);
 	my $i = 0;
@@ -779,6 +782,45 @@ sub _reject_transfer {
 	return WWW::CNic::Response::RejectTransfer->new($self->{_response}->{_raw});
 }
 
+sub _list_outstanding_domains {
+	my $self = shift;
+	die("Missing username") if $self->{_username} eq '';
+	die("Missing password") if $self->{_password} eq '';
+	my %params = (
+				user		=> $self->{_username},
+				password	=> $self->_crypt_md5($self->{_password}),
+				test		=> $self->{_test},
+	);
+	my $url = "$self->{_base}/list_outstanding_domains";
+	my $req = POST($url, \%params);
+	$self->{_response}->{_raw} = $self->_get($req);
+	use WWW::CNic::Response::ListOutstandingDomains;
+	return WWW::CNic::Response::ListOutstandingDomains->new($self->{_response}->{_raw});
+}
+
+sub _submit_payment_batch {
+	my $self = shift;
+	die("Missing username") if $self->{_username} eq '';
+	die("Missing password") if $self->{_password} eq '';
+	die("Missing domains") if scalar(@{$self->{_params}->{domains}}) < 1;
+	die("Missing method") if $self->{_params}->{method} eq '';
+	my %params = 	(
+				user		=> $self->{_username},
+				password	=> $self->_crypt_md5($self->{_password}),
+				test		=> $self->{_test},
+				method		=> $self->{_params}->{method},
+			);
+	my $i = 0;
+	foreach my $domain(@{$self->{_params}->{domains}}) {
+		$params{"domains[$i]"} = $domain;
+		$i++;
+	}
+	my $req = POST("$self->{_base}/submit_payment_batch", \%params);
+	$self->{_response}->{_raw} = $self->_get($req);
+	use WWW::CNic::Response::SubmitPaymentBatch;
+	return WWW::CNic::Response::SubmitPaymentBatch->new($self->{_response}->{_raw});
+}
+
 sub _get {
 	my ($self, $request) = @_;
 	my $response = $self->{_agent}->request($request);
