@@ -1,7 +1,7 @@
 # Copyright (c) 2007 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: Cookbook.pm,v 1.39 2007/04/26 16:16:07 gavin Exp $
+# $Id: Cookbook.pm,v 1.41 2007/07/24 11:35:59 gavin Exp $
 
 package WWW::CNic::Cookbook;
 use vars qw($VERSION);
@@ -487,7 +487,10 @@ The meaning of these fields is identical to those described in the "Creating a H
 		password	=> $passwd
 	);
 
-	$query->set(domains => ['example1.uk.com', 'example2.uk.com']);
+	$query->set(
+		domains => ['example1.uk.com', 'example2.uk.com'],
+		period	=> 2, # 2 years
+	);
 
 	my $response = $query->execute;
 
@@ -938,6 +941,86 @@ You can use this command to retrieve a list of domains against your handle. The
 
 This command allows you to retrieve pricing information for your reseller account. You must specify a C<type> parameter, which can be either 'C<registration>' (the default) or 'C<renewal>'.
 
+=head2 Listing Outstanding Domains
+
+	use WWW::CNic;
+	use strict;
+
+	my $query = WWW::CNic->new(
+		use_ssl		=> 1,
+		command		=> 'list_outstanding_domains',
+		username	=> $handle,
+		password	=> $password,
+	);
+
+	my $response = $query->execute;
+
+	if ($response->is_error) {
+		printf("Error: %s\n", $response->error);
+	}
+
+	foreach my $domain ($response->domains) {
+		printf(
+			"Domain: %s\n".
+			"\tExpired: %s\n".
+			"\tDocument: %s #%d\n".
+			"\tIssued on: %s\n".
+			"\tAmount: %s%01.2f\n".
+			"\tType: %s\n".
+			"\tYears: %s\n".
+			"\tBatch: %d\n\n",
+			$domain->{domain},
+			$domain->{expiry},
+			($domain->{invoice} > 0 ? 'Invoice' : 'Pro forma'),
+			($domain->{invoice} > 0 ? $domain->{invoice} : $domain->{proforma}),
+			$domain->{date},
+			$domain->{currency},
+			$domain->{amount},
+			$domain->{type},
+			$domain->{years},
+			$domain->{batch},
+		);
+	}
+
+This command retrieves a list of all unpaid invoice items for domain names on your account. Each registration or renewal causes on item to be added to an invoice (or pro forma invoice for VAT-paying registrars).
+
+You can combine this function with the one below to automatically submit payment advice for invoices (you still need to send us the actual money!).
+
+=head2 Submitting Payment Advice
+
+	use WWW::CNic;
+	use strict;
+
+	my $query = WWW::CNic->new(
+		use_ssl		=> 1,
+		command		=> 'submit_payment_batch',
+		username	=> $handle,
+		password	=> $password,
+	);
+
+	$query->set('method', 'CH'); # CH for a cheque, BA for a bank transfer
+	$query->set('domains', \@domains);
+
+	my $response = $query->execute;
+
+	if ($response->is_error) {
+		printf("Error: %s\n", $response->error);
+	}
+
+	printf(
+		"Payment Batch #%d created for %d items at %s%01.2f (plus %s%01.2f VAT)\n",
+		$response->response('batch'),
+		$response->response('items'),
+		$response->response('currency'),
+		$response->response('amount'),
+		$response->response('currency'),
+		$response->response('vat'),
+	);
+
+You can use this function to submit advice about a payment for outstanding domain registrations and renewals. Combining this function with the function above allows you to retrieve a list of outstanding domain names, filter them based on whether or not you've received payment or a deletion request from your customer, and generate a payment batch that can be associated with a cheque or wire transfer issued by your company.
+
+Please note that you will need to factor in the amount of VAT (if applicable) - this amount is available in the response object.
+
 =head1 Feedback
 
 We're always keen to find out about how people are using our Toolkit system, and we're happy to accept any comments, suggestions or problems you might have. If you want to get in touch, please e-mail L<toolkit@centralnic.com>.
